@@ -30,18 +30,27 @@
   function MagnumAPI($timeout, apiService, toastService, gettext) {
     var service = {
       createCluster: createCluster,
+      updateCluster: updateCluster,
       getCluster: getCluster,
       getClusters: getClusters,
       deleteCluster: deleteCluster,
       deleteClusters: deleteClusters,
       createClusterTemplate: createClusterTemplate,
+      updateClusterTemplate: updateClusterTemplate,
       getClusterTemplate: getClusterTemplate,
       getClusterTemplates: getClusterTemplates,
       deleteClusterTemplate: deleteClusterTemplate,
       deleteClusterTemplates: deleteClusterTemplates,
       showCertificate: showCertificate,
       signCertificate: signCertificate,
-      downloadTextAsFile: downloadTextAsFile
+      rotateCertificate: rotateCertificate,
+      getStats: getStats,
+      getQuotas: getQuotas,
+      getQuota: getQuota,
+      createQuota: createQuota,
+      updateQuota: updateQuota,
+      deleteQuota: deleteQuota,
+      getNetworks: getNetworks
     };
 
     return service;
@@ -57,6 +66,13 @@
         });
     }
 
+    function updateCluster(id, params) {
+      return apiService.patch('/api/container_infra/clusters/' + id, params)
+        .error(function() {
+          toastService.add('error', gettext('Unable to update cluster.'));
+        });
+    }
+
     function getCluster(id) {
       return apiService.get('/api/container_infra/clusters/' + id)
         .error(function() {
@@ -98,6 +114,13 @@
         });
     }
 
+    function updateClusterTemplate(id, params) {
+      return apiService.patch('/api/container_infra/cluster_templates/' + id, params)
+        .error(function() {
+          toastService.add('error', gettext('Unable to update cluster template.'));
+        });
+    }
+
     function getClusterTemplate(id) {
       return apiService.get('/api/container_infra/cluster_templates/' + id)
         .error(function() {
@@ -146,23 +169,82 @@
         });
     }
 
-    function downloadTextAsFile(text, filename) {
-      // create text file as object url
-      var blob = new Blob([ text ], { "type" : "text/plain" });
-      window.URL = window.URL || window.webkitURL;
-      var fileurl = window.URL.createObjectURL(blob);
+    function rotateCertificate(id) {
+      return apiService.delete('/api/container_infra/certificates/' + id, [id])
+        .error(function() {
+          toastService.add('error', gettext('Unable to rotate the certificate.'));
+        });
+    }
 
-      // provide text as downloaded file
-      $timeout(function() {
-        //Update view
-        var a = angular.element('<a></a>');
-        a.attr("href", fileurl);
-        a.attr("download", filename);
-        a.attr("target", "_blank");
-        angular.element(document.body).append(a);
-        a[0].click();
-        a.remove();
-      }, 0);
+    ///////////
+    // Stats //
+    ///////////
+
+    function getStats() {
+      return apiService.get('/api/container_infra/stats/')
+        .error(function() {
+          toastService.add('error', gettext('Unable to retrieve the stats.'));
+        });
+    }
+
+    //////////////
+    // Quotas //
+    //////////////
+
+    function getQuotas() {
+      return apiService.get('/api/container_infra/quotas/')
+        .error(function() {
+          toastService.add('error', gettext('Unable to retrieve the quotas.'));
+        });
+    }
+
+    function getQuota(projectId, resource, suppressError) {
+      var promise = apiService.get('/api/container_infra/quotas/' + projectId + '/' + resource);
+      return suppressError ? promise : promise.error(function() {
+        toastService.add('error', gettext('Unable to retrieve the quota.'));
+      });
+    }
+
+    function createQuota(projectId, resource, params) {
+      return apiService.post('/api/container_infra/quotas/' + projectId + '/' + resource, params)
+        .error(function() {
+          toastService.add('error', gettext('Unable to create quota.'));
+        });
+    }
+
+    function updateQuota(projectId, resource, params) {
+      return apiService.patch('/api/container_infra/quotas/' + projectId + '/' + resource, params)
+        .error(function() {
+          toastService.add('error', gettext('Unable to update quota.'));
+        });
+    }
+
+    function deleteQuota(projectId, resource, suppressError) {
+      var promise = apiService.delete('/api/container_infra/quotas/' + projectId + '/' + resource);
+      return suppressError ? promise : promise.error(function() {
+        var msg = gettext('Unable to delete the quota with project id: %(projectId)s and ' +
+          'resource: %(resource)s.');
+        toastService.add('error',
+          interpolate(msg, { projectId: projectId, resource: resource }, true));
+      });
+    }
+
+    //////////////////
+    // Networks     //
+    //////////////////
+
+    /**
+     * @name getNetworks
+     * @description
+     * Get a list of networks for a tenant including external and private.
+     * Also, each network has subnets.
+     * @returns {Object} An object with property "items". Each item is a network.
+     */
+    function getNetworks() {
+      return apiService.get('/api/container_infra/networks/')
+        .error(function () {
+          toastService.add('error', gettext('Unable to retrieve the networks.'));
+        });
     }
   }
 }());
